@@ -2,6 +2,7 @@ from pathlib import Path
 import time
 import pandas as pd
 import numpy as np
+import shutil
 
 from github2pandas.issues import Issues
 from github2pandas.pull_requests import PullRequests
@@ -105,8 +106,14 @@ class Github_data_extractor():
                         repo.full_name.split('/')[1],
                     )
                     repo_base_folder.mkdir(parents=True, exist_ok=True)
-                    Github_data_extractor.CLASSES[content_element](repo, repo_base_folder, github_token)
-                    status.loc[repo.full_name, content_element] = pd.Timestamp.now()
+                    try:
+                        Github_data_extractor.CLASSES[content_element](repo, repo_base_folder, github_token)
+                    except IndexError as e:
+                        print(e)
+                        shutil.rmtree(repo_base_folder)
+                        status.loc[repo.full_name, content_element] = np.nan
+                    else:
+                        status.loc[repo.full_name, content_element] = pd.Timestamp.now()
             else:
                 print(f"{content_element} not known in github2pandas toolchain!")
                 print("Please check spelling")
